#!/bin/bash
# Copyright:	None.  This script has been placed in the public domain
#		by its author, Ron Burkey.
# Filename:	TTP-rip.sh
# Purpose:	This script is part of the TeachToPod.sh group
#		of scripts (see http://www.sandroid.org/TeachToPod).  
#		This particular script rips the lecture tracks
#		from an ISO image of a Teaching Company DVD, 
#		recoding to some more-desirable audio/video format.
#		As given, the recoding is for 320x240 m4v files
#		suitable for my own iPod Classic, but practically
#		any other format can be chosen by changing the 
#		parameters of the invocation of HandBrakeCLI.
# Mod history:	2010-12-13 RSB	Wrote.
#		2010-12-14 RSB	Added the VideoFormat option.

# This is a script for ripping Teaching Company lectures from an ISO
# file containing a DVD image.  It is intended to be used with 
# TTP-meta.sh and TTP-scrape.sh.  It assumes that the ISO file is named
# 1.iso, 2.iso, etc., indicating its place in the set (or else
# 01.iso, 02.iso, ..., 10.iso, 11.iso, etc. for sets with 10 or 
# more DVDs in them).  Only the tracks long enough to be lectures
# are ripped, and they are put in files named 11.m4v, 12.m4v, ...
# (or 011.m4v, 012.m4v, etc. for 10+ disk sets). (Or .mp3 for audio.)
# For example, to  rip 3.iso, do "TTP-rip.sh 3".
#
# The full usage is:
#	TTP-rip.sh DiscNum [Audio [VideoFormat]]
#
# If the optional Audio argument is present (it can have any non-blank
# value), then audio tracks are ripped to mp3 rather than ripping video.
# By default the transcoding options for the video encoding are chosen for 
# iPod Classic, which is what I have.  This default is used either by 
# omitting the VideoFormat command-line option or by setting it to 
# "classic".  Setting it to "ipad" produces the same result except at 
# 640x480 rather than 320x240, and is presumably good for the iPad even
# though I have no way to check it out.  Lots of other choices are possible 
# if you want to tweak the HandBrakeCLI command that does the coding.

# Parse the command-line options.
if test "$1" == ""
then
	echo No source specified.
	exit 1
fi
base="$1"
Audio="$2"
source="$base".iso
if test ! -f "$source"
then
	echo Source file "$source" does not exist.
	exit 1
fi
VideoFormat="$3"
case r_$VideoFormat in
	r_ | r_classic)
		vb=400
		width=320
		height=240
		;;
	r_ipad)
		vb=2000
		width=640
		height=480
		;;
	*)
		echo Illegal VideoFormat option.
		exit 1
		;;
esac

# Get a list of tracks and their durations into the
# tracks[] array variable.
HandBrakeCLI -i $source -t 0 2>&1 | grep '+ vts [0-9]' >tracks.txt
tracks=
declare -a tracks
mapfile -t tracks <tracks.txt
numtracks=`wc -l tracks.txt | grep --only-matching '[0-9][0-9]*'`
echo $numtracks tracks found.

# Loop on the tracks.  Since all Teaching Company lectures are nominally
# either 30 minutes or 45 minutes in duration, and all of the other tracks
# will be very short things, we can simply choose the appropriate tracks
# on the basis of size.
cutoff=200000
lecture=0
for n in `seq 0 $((numtracks-1))`
do
	track=`echo "${tracks[$n]}" | grep --only-matching 'vts [0-9]*' | grep --only-matching '[0-9]*'`
	size=`echo "${tracks[$n]}" | grep --only-matching '[0-9]* blocks' | grep --only-matching '[0-9]*'`
	echo "Processing $n (track $track, $size blocks) ..."
	# Transparently ignore all tracks that are
	# too short.  For the sake of argument, we'll
	# say that a track has to be at least $cutoff
	# blocks long.
	if test "$size" -lt $cutoff
	then
		echo "Too short, ignoring."
	else
		lecture=$((lecture+1))
		echo "Lecture $lecture ..."
		if test "$Audio" == ""
		then
			if test -f "$base"$lecture.m4v
			then
				echo "$base"$lecture.m4v already exists ... skipping.
			else
				HandBrakeCLI \
					--input $source \
					--output "$base"$lecture.m4v \
					--title $track \
					--markers \
					--ipod-atom \
					--encoder ffmpeg \
					--vb $vb \
					--two-pass \
					--audio 1 \
					--aencoder faac \
					--ab 128 \
					--mixdown stereo \
					--aname "Unknown (AC3) (2.0 ch)" \
					--width $width \
					--height $height
			fi
		else
			if test -f "$base"$lecture.mp3
			then
				echo "$base"$lecture.mp3 already exists ... skipping.
			else
				transcode -i $source -x dvd -T $track,-1 -a 0 -y null,tcaud -m "$base"$lecture.mp3
			fi
		fi
	fi
done

