#!/bin/bash
# Copyright:	None.  This script has been placed in the public domain
#		by its author, Ron Burkey.
# Filename:	TTP-scrape.sh
# Purpose:	This script is part of the TeachToPod.sh group
#		of scripts (see http://www.sandroid.org/TeachToPod).  
#		This particular script scrapes info about a Teaching
#		Company course from the Teaching Company's website.
# Mod history:	2010-12-13 RSB	Wrote.

# This script scrapes The Teaching Company website, given a 
# course number, and creates a file titles.txt suitable for
# use with the script TTP-meta.sh.  The information needed from the
# website is:
#	The number of lectures.
#	The lengths of the lectures, in minutes.
#	The title of the course.
#	The titles of the individual lectures.
# By default, the number of DVDs and the number of lectures per 
# DVD (the first two numbers in the output file) will be deduced 
# from the website, but if this isn't possible they'll default to
# 6 and 6.  They can also be edited manually or else added 
# to the command line:
#	../TTP-scrape.sh CourseNum [Disks [PerDisk]]

# Parse the command-line arguments.
if test "$1" == ""
then
	echo No course-number specified.
	exit 1
fi
disks=
perdisk=
if test "$2" != ""
then
	disks=$2
fi
if test "$3" != ""
then
	perdisk=$3
fi

# Fetch the web-page describing the course.
rm titles.txt
course=$1
filename="course_detail.aspx?cid=$course"
wget "http://www.teach12.com/tgc/courses/course_detail.aspx?cid=$course"
if grep --ignore-case -c "Page Not Found" "course_detail.aspx?cid=$course" >/dev/null
then
	echo "Is the course number correct?"
	exit 1
fi

# Parse the web-page to get the info we want from it, other than
# the names of the lectures.
numlectures=`grep --only-matching 'NumberOfLecture">[0-9][0-9]*' $filename | grep --only-matching '[0-9]*'`
minutesperlecture=`grep --only-matching 'LectureLength">[0-9][0-9]*' $filename | grep --only-matching '[0-9]*'`
if test "$numlectures" != "" || "$minutesperlecture" != ""
then
	if test "$perdisk" == ""
	then
		# Really 180 minutes per disk, but add a little slop.
		perdisk=$((200/minutesperlecture))
		echo Found $minutesperlecture minutes per lecture, deduced $perdisk lectures per disk.
	fi
	if test "$disks" == ""
	then
		disks=$(((numlectures+perdisk-1)/perdisk))
		echo Found $numlectures total lectures, deduced $disks DVDs in the set.
	fi
fi
if test "$disks" == ""
then
	disks=6
fi
if test "$perdisk" == ""
then
	perdisk=6
fi

# Parse the web-page to get the lecture names, and then normalize 
# those names to get rid of junk that will cause us problems in 
# processing later.
echo $disks >titles.txt
echo $perdisk >>titles.txt
grep --only-matching 'course_detail.aspx?cid=[[:digit:]]*">[^<]*</a></li>' $filename | \
	sed 	-e 's/course_detail.aspx?cid=[[:digit:]]*">//' \
		-e 's@</a>.*@@' \
	>>titles.txt
echo $course >>titles.txt
grep --only-matching '<li>.*Lecture_Desc' $filename | \
	sed 	-e 's/ (<a.*//' \
		-e 's/<[^>]*>//g' \
		-e 's/&ndash;/-/g' \
		-e 's/&mdash;/ -- /g' \
		-e 's/"//g' \
		-e 's/&[[:alpha:]]*;//g' \
		-e 's/^[[:space:]]*//' \
		-e 's/[[:space:]]*$//' \
	>>titles.txt
	
# Get rid of the web-page we just downloaded.
rm "course_detail.aspx?cid=$course"

