#!/bin/bash
# Copyright:	None.  This script has been placed in the public domain
#		by its author, Ron Burkey.
# Filename:	TeachToIpod.sh
# Purpose:	This script is part of the TeachToPod.sh group
#		of scripts (see http://www.sandroid.org/TeachToPod).  
#		This is the top-level script that ties everything
#		together and invokes all of the other scripts
#		as needed.
# Mod history:	2010-12-13 RSB	Wrote.
#		2010-12-14 RSB	Added the VideoFormat option, and
#				in particular, VideoFormat=ipad.

# This script combines pulling ISO files from a set of
# Teaching Company DVDs, along with the TTP-scrape.sh, TTP-rip.sh,
# and TTP-meta.sh scripts, to create a set of media files with
# embedded metadata for the individual lectures.  The metadata
# is scraped from The Teaching Company's website.  As given,
# these are most suitable for use on an iPod Classic, but
# TTP-rip.sh could be varied to give other formats.
#
# Usage:
#	TeachToPod.sh CourseNumber [AudioVideo [VideoFormat [DVDdevice [Command]]]]
#
# DVDdevice defaults to /dev/sr0.  Command can be any command
# executed periodically while waiting for a DVD to be inserted.
# (Put it in quotes if it contains spaces.)  Principally useful,
# I suppose, for playing an audio file to tell you that a 
# DVD change needs to be made, and I've made the default a 
# sound that's reasonably convenient for me.  You may or may
# not have this particular sound or this particular player installed.
#
# By default (no AudioVideo command-line parameter or AudioVideo=video), 
# TeachToPod.sh will create video files.  However, it can also be used 
# to create separate mp3 audio files (AudioVideo=both), or to create *only* 
# mp3 files without video files (AudioVideo=audio).  With AudioVideo=none,
# it will create just the ISO files, but neither audio nor video files.
#
# By default (no VideoFormat command-line parameter or VideoFormat=classic), 
# the video format created will be 320x240 m4v, suitable for an iPod Classic.
# If VideoFormat=ipad, it will instead be 640x480 m4v.

# Parse command-line arguments.
AudioVideo=$2
Video=
Audio=
case r_$AudioVideo in
	r_ | r_video) 
		Video=yes
		;;
	r_audio)
		Audio=yes
		;;
	r_both)
		Video=yes
		Audio=yes
		;;
	r_none)
		;;
	*)
		echo "Illegal audio/video option."
		exit 1
		;;
esac
VideoFormat=$3
case r_$VideoFormat in
	r_ | r_classic)
		VideoFormat=
		;;
	r_ipad)
		VideoFormat=ipad
		;;
	*)
		echo "Illegal video-format option."
		exit 1
esac
DVDdevice=/dev/sr0
if test "$4" != ""
then
	DVDdevice="$4"
fi
EXEDIR=`echo $0 | grep --only-matching '^.*/'`
command="play -q $EXEDIR/TTP-bell.wav"
if test "$5" != ""
then
	command="$5"
fi

# Scrape the Teaching Company website for the info on the
# specified course number.
rm titles.txt everything.log course_detail* &>/dev/null
TTP-scrape.sh $1
if test ! -f titles.txt
then
	echo "Could not determine the characteristics of this"
	echo "course ... i.e., scrape.sh failed."
	exit 1
fi

# Read titles.txt into the titles[] array variable.
titles=
declare -a titles
mapfile -t titles <titles.txt
disks=${titles[0]}

# Suck in all of the DVDs to ISO files
for n in `seq -w 1 $disks`
do
	if test -f $n.iso
	then
		echo "$n.iso has already been created ... skipping."
		continue;
	fi
	while true
	do
		echo "Please insert DVD $n."
		$command
		if mount | grep -c "$DVDdevice" >/dev/null
		then
			break
		fi
		sleep 3
	done
	echo DVD found.
	echo Pulling $n.iso from the DVD ...
	dd if="$DVDdevice" of=$n.iso
	eject
done
for n in `seq 1 5`
do
	$command
	sleep 3
done

# Rip from the ISO files to audio and/or video files.
for n in `seq -w 1 $disks`
do
	if test "$Video" != ""
	then
		echo Ripping video tracks from $n.iso ...
		TTP-rip.sh $n "" $VideoFormat 2>&1 >>everything.log
	fi
	if test "$Audio" != ""
	then
		echo Ripping audio tracks from $n.iso ...
		TTP-rip.sh $n audio 2>&1 >>everything.log
	fi
done

# Add the metadata to the audio and/or video files.
if test "$Video" != ""
then 
	echo Adding metadata to the individual video lectures ...
	TTP-meta.sh 2>&1 >>everything.log
fi
if test "$Audio" != ""
then 
	echo Adding metadata to the individual audio lectures ...
	TTP-meta.sh audio 2>&1 >>everything.log
fi

# Get rid of all the ISO files
#for n in `seq -w 1 $disks`
#do
#	rm $n.iso
#done

echo All done.  Consult everything.log if there were problems.
for n in `seq 1 5`
do
	$command
	sleep 3
done


